==> aws-java-sdk-1.1.9-sources.jar: com/amazonaws/services/ec2/model/AttachVpnGatewayResult.java <==
/*
 * Copyright 2010-2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * <p>
 * 
 * </p>
 */
public class AttachVpnGatewayResult {

    /**
     * 
     */
    private VpcAttachment vpcAttachement;

    /**
     * 
     *
     * @return 
     */
    public VpcAttachment getVpcAttachement() {
        return vpcAttachement;
    }
    
    /**
     * 
     *
     * @param vpcAttachement 
     */
    public void setVpcAttachement(VpcAttachment vpcAttachement) {
        this.vpcAttachement = vpcAttachement;
    }
    
    /**
     * 
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param vpcAttachement 
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public AttachVpnGatewayResult withVpcAttachement(VpcAttachment vpcAttachement) {
        this.vpcAttachement = vpcAttachement;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        sb.append("VpcAttachement: " + vpcAttachement + ", ");
        sb.append("}");
        return sb.toString();
    }
    
}

==> aws-java-sdk-1.3.26-sources.jar: com/amazonaws/services/ec2/model/AttachVpnGatewayResult.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.ec2.model;

/**
 * <p>
 * 
 * </p>
 */
public class AttachVpnGatewayResult {

    /**
     * 
     */
    private VpcAttachment vpcAttachement;

    /**
     * 
     *
     * @return 
     */
    public VpcAttachment getVpcAttachement() {
        return vpcAttachement;
    }
    
    /**
     * 
     *
     * @param vpcAttachement 
     */
    public void setVpcAttachement(VpcAttachment vpcAttachement) {
        this.vpcAttachement = vpcAttachement;
    }
    
    /**
     * 
     * <p>
     * Returns a reference to this object so that method calls can be chained together.
     *
     * @param vpcAttachement 
     *
     * @return A reference to this updated object so that method calls can be chained 
     *         together. 
     */
    public AttachVpnGatewayResult withVpcAttachement(VpcAttachment vpcAttachement) {
        this.vpcAttachement = vpcAttachement;
        return this;
    }
    
    
    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (vpcAttachement != null) sb.append("VpcAttachement: " + vpcAttachement + ", ");
        sb.append("}");
        return sb.toString();
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;
        
        hashCode = prime * hashCode + ((getVpcAttachement() == null) ? 0 : getVpcAttachement().hashCode()); 
        return hashCode;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
    
        if (obj instanceof AttachVpnGatewayResult == false) return false;
        AttachVpnGatewayResult other = (AttachVpnGatewayResult)obj;
        
        if (other.getVpcAttachement() == null ^ this.getVpcAttachement() == null) return false;
        if (other.getVpcAttachement() != null && other.getVpcAttachement().equals(this.getVpcAttachement()) == false) return false; 
        return true;
    }
    
}
